module.exports = defineTest({
	description: 'globally called function should be included if it modifies an exported value (#112)'
});
